'use strict';

/**
 * @param {Egg.Application} app - egg application
 */
module.exports = app => {
  const { router, controller } = app;
  router.get('/', controller.home.index);
  router.post('/api/visit/login', controller.login.login); // 用户登录
  router.post('/api/visit/wxlogin', controller.login.wxlogin); // 微信用户登录
  router.resources('user', '/api/visit/user', controller.user); // index、create、show、destroy

  router.resources('doctor', '/api/visit/doctor', controller.doctor); // index、create、show、destroy
  router.post('doctor', '/api/visit/doctor/:id', controller.doctor.update);
  router.get('doctor', '/api/visit/doctor/findopenid', controller.doctor.findopenid);
  router.post('doctor', '/api/visit/doctor/:id/bind', controller.doctor.updateopenid);

  router.resources('nurse', '/api/visit/nurse', controller.nurse); // index、create、show、destroy
  router.post('nurse', '/api/visit/nurse/:id', controller.nurse.update);
  router.post('nurse', '/api/visit/nurse/login', controller.nurse.login);
  router.resources('group', '/api/visit/group', controller.group); // index、create、show、destroy
  router.get('/api/visit/group/:id/info', controller.group.info);
  router.post('/api/visit/group/:id/info', controller.group.info);
  // 群里患者接口
  router.resources('grouppatients', '/api/visit/grouppatients', controller.grouppatients); // index、create、show
  router.get('/api/visit/grouppatients/:groupid/patients', controller.grouppatients.index); // index
  router.get('/api/visit/grouppatients/:groupid/patients/fetch', controller.grouppatients.fetch); // index
  router.post('/api/visit/grouppatients/:groupid/update/:id', controller.grouppatients.update); // update
  router.post('/api/visit/grouppatients/:groupid/destroy/:id', controller.grouppatients.destroy); // destroy

  router.resources('patient', '/api/visit/patient', controller.patient); // index、create、show、destroy
  router.get('/api/visit/patient/:id/info', controller.patient.info);
  router.get('/api/visit/patient/:id/doctors', controller.patient.doctors);
  router.get('/api/visit/patient/:id/groups', controller.patient.groups);
  router.post('/api/visit/patient/:id/info', controller.patient.info);
  router.get('patient', '/api/visit/patient/findopenid', controller.patient.findopenid);
  // 患者病历接口
  router.resources('patientemrs', '/api/visit/patientemrs', controller.patientemrs); // index、create、show
  router.get('/api/visit/patientemrs/:patientid/emrs', controller.patientemrs.index); // index
  router.get('/api/visit/patientemrs/:patientid/emrs/fetch/:emrid', controller.patientemrs.fetch); // index
  router.post('/api/visit/patientemrs/:patientid/create', controller.patientemrs.create); // update
  router.post('/api/visit/patientemrs/:patientid/update/:id', controller.patientemrs.update); // update
  router.delete('/api/visit/patientemrs/:patientid/destroy/:id', controller.patientemrs.destroy); // destroy

  router.get('/api/visit/rooms', controller.room.index); // index
  router.get('/api/visit/rooms/destroy/:id', controller.room.destroy); // destroy
  router.get('/api/visit/chat', controller.chat.index); // index
  router.post('/api/visit/chat/create', controller.chat.create); // update
  router.delete('/api/visit/chat/destroy/:id', controller.chat.destroy); // destroy

  router.get('/api/visit/groupchat', controller.groupchat.index); // index
  router.post('/api/visit/groupchat/create/:groupid', controller.groupchat.create); // update
  router.delete('/api/visit/groupchat/destroy/:id', controller.groupchat.destroy); // destroy


  // 微信认证，生成包含微信用户信息的token写入cookie
  router.get('/api/visit/auth', controller.weixin.auth);
  router.get('/api/visit/authBack', controller.weixin.authBack);
  router.post('/api/visit/wxpaysign', controller.wxpay.wxpaysign); // 取得支付签名
  router.post('/api/visit/wxpayback', controller.wxpay.wxpaysignback); // 取得支付签名
  // 打赏管理
  router.get('/api/visit/doctormoney', controller.doctormoney.index); // index
  router.post('/api/visit/doctormoney/create/:doctorid', controller.doctormoney.create); // create
  router.delete('/api/visit/doctormoney/destroy/:id', controller.doctormoney.destroy); // destroy


  // 微信扫码登录，生成包含微信用户信息的token，存入redis
  router.post('/api/visit/qrcode/create', controller.qrcode.create); // 创建二维码
  router.post('/api/visit/qrcode/creategroup', controller.qrcode.createQrcode); // 创建群二维码

  router.post('/api/visit/qrcode/:qrcode/check', controller.qrcode.check); // 检查二维码状态
  router.get('/api/visit/qrcode/:qrcode/scan', controller.qrcode.scan); // 扫码确认页面
  router.post('/api/visit/qrcode/:qrcode/login', controller.qrcode.login); // 扫码登录确认
  router.post('/api/visit/qrcode/:qrcode/token', controller.qrcode.token); // 换取微信认证码

  // 广告
  router.resources('adv', '/api/visit/adv', controller.adv); // index、create、show、destroy
  router.post('/api/visit/adv/update/:id', controller.adv.update);

  // 医疗科普文章
  router.resources('article', '/api/visit/article', controller.article); // index、create、show、destroy
  router.post('/api/visit/article/update/:id', controller.article.update);
};
